@@ -252,7 +252,6 @@ class Dxr_Publisher:
         if mqttc is None:
             mqttc = Mqtt()
         try:
-            # print(f'self.data_type:{self.data_type}')
             if self.data_type:
                 if mqttc is not None:
                     if mqttc.is_connected():
@@ -298,7 +297,6 @@ class Dxr_Publisher:
         if await_topic is None:
             return None
         await_topic = await_topic.replace('pc', 'client')
-        # print('await_publish: ' + await_topic)
         cond = get_cond(await_topic)
         if cond is None:
             return None
@@ -308,6 +306,23 @@ class Dxr_Publisher:
             cond.wait(timeout)
         return callback_dit[await_topic]['msg']
 
+    def stop_awit_publish(self, topic=None):
+        global callback_dit, mqttc
+        if topic is None:
+            await_topic = self.topic + '_response'
+        else:
+            if isinstance(topic, str):
+                await_topic = topic
+            else:
+                await_topic = topic.topic
+        if await_topic is None:
+            return None
+        await_topic = await_topic.replace('pc', 'client')
+        cond = get_cond(await_topic)
+        if cond is None:
+            return None
+        cond.set()
+        cond.clear()
 
 class Dxr_UnSubscriber:
     def __init__(self, topic):
